<template>
  <el-dialog
    v-diadrag
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="120px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="24">
          <el-form-item label="规则编号" prop="ruleNo">
            <el-input v-model="dataForm.ruleNo" placeholder="规则编号">
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="规则名称" prop="ruleName">
            <el-input v-model="dataForm.ruleName" placeholder="规则名称">
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="工序" prop="operationName">
            <el-input v-model="dataForm.operationName" placeholder="工序">
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openOperationDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="检测方式" prop="inspectionType">
            <el-select
              v-model="dataForm.inspectionType"
              filterable
              clearable
              placeholder="请选择"
              style="width: 100%;"
              :disabled="status"
            >
              <el-option
                v-for="(item, index) in detectionTypeOptions"
                :label="item.label"
                :value="item.value"
                :key="index"
              >
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="24">
          <el-form-item label="备注" prop="remark">
            <el-input v-model="dataForm.remark" placeholder="备注"> </el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
    <operationDialog
      :currshowlist.sync="showOperation"
      @listenToOperationEvent="selectOperation"
    />
  </el-dialog>
</template>
<script>
import {
  addTestApplyRule,
  getTestApplyRule,
  putTestApplyRule
} from '@/api/quality/detectionrules'
import operationDialog from '@/views/common/operation.vue'
import { remote } from '@/api/admin/dict'

export default {
  components: {
    operationDialog
  },
  data() {
    return {
      status: false,
      visible: false,
      loading: false,
      showPart: false,
      dataForm: {
        id: 0,
        inspectionType: null,
        operationNo: null,
        operationName: null,
        remark: null,
        ruleName: null,
        ruleNo: null
      },
      dataRule: {
        ruleNo: [
          { required: true, message: '规则编号号不能为空', trigger: 'blur' }
        ],
        ruleName: [
          { required: true, message: '规则名称不能为空', trigger: 'blur' }
        ],
        operationName: [
          { required: true, message: '工序不能为空', trigger: 'change' }
        ],
        inspectionType: [
          { required: true, message: '请选择检测方式', trigger: 'change' }
        ]
      },
      options: [],
      detectionTypeOptions: [],
      isSubmit: false,
      showOperation: false
    }
  },
  methods: {
    init(id) {
      this.status = false
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getTestApplyRule(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },

    openOperationDialog() {
      this.showOperation = true
    },
    selectOperation(operation) {
      if (operation) {
        this.dataForm.operationNo = operation.operationNo
        this.dataForm.operationName = operation.name
      }
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            putTestApplyRule(this.dataForm)
              .then((data) => {
                this.$message.success('修改成功')
                this.visible = false
                this.isSubmit = false
                this.$emit('refreshDataList')
              })
              .catch((error) => {
                this.isSubmit = false
                console.log(error)
              })
          } else {
            addTestApplyRule(this.dataForm)
              .then((data) => {
                this.$message.success('添加成功')
                this.visible = false
                this.isSubmit = false
                this.$emit('refreshDataList')
              })
              .catch((error) => {
                this.isSubmit = false
                console.log(error)
              })
          }
        } else {
          this.isSubmit = false
        }
      })
    },
    getDetectionTypeDict() {
      remote('apply_report_type').then((response) => {
        if (response.data.code === 0) {
          this.detectionTypeOptions = response.data.data
        } else {
          this.detectionTypeOptions = []
        }
      })
    }
  },
  mounted() {
    this.getDetectionTypeDict()
  }
}
</script>
